@@ -12,10 +12,6 @@ extern "C"
 {
 #endif
 
-/// Returns a null pointer.
-/// Returns: `void *null` - A null pointer.
-NSTDAPI void *nstd_core_def_null();
-
 /// Represents a size of any type, such as a memory block.
 typedef size_t NSTDUSize;
 /// Represents a signed size.
