@@ -1,12 +1,4 @@
-#include "core/arch.h"
-#include "core/char_types.h"
-#include "core/def.h"
-#include "core/float_types.h"
-#include "core/int_types.h"
-#include "core/mem.h"
-#include "core/platform.h"
-#include "core/pointer.h"
-#include "core/slice.h"
+#include "core/core.h"
 #include "std/alloc.h"
 #include "std/audio.h"
 #include "std/collections/vec.h"
